ArrayConvexPolytope

Struct ArrayConvexPolytope 

pub struct ArrayConvexPolytope<const P: usize, const V: usize> {
    pub planes: [(Vec3, f32); P],
    pub vertices: [Vec3; V],
    pub obb: Cuboid,
}
A convex polytope defined by half-planes and vertices, using const generics so it can be constructed and stored in const / static contexts.

P is the number of half-planes, V is the number of vertices.

This is mostly meant for usage with codegen where you statically define obstacles based on some sort of file at build time, and want to be able to use them in const contexts.

Fields

planes: [(Vec3, f32); P]vertices: [Vec3; V]obb: Cuboid

Implementations

Source

impl<const P: usize, const V: usize> ArrayConvexPolytope<P, V>

pub const fn new( planes: [(Vec3, f32); P], vertices: [Vec3; V], obb: Cuboid, ) -> Self

Create a new const convex polytope. This is a const fn so it can be used in const and static initializers.

Source

impl<const P: usize, const V: usize> ArrayConvexPolytope<P, V>

pub fn scale(&mut self, factor: f32)

Source

impl<const P: usize, const V: usize> ArrayConvexPolytope<P, V>

pub fn translate(&mut self, offset: Vec3A)

pub fn rotate_mat(&mut self, mat: Mat3A)

pub fn rotate_quat(&mut self, quat: Quat)

pub fn transform(&mut self, mat: Affine3A)