pub struct Cylinder {
pub p1: Vec3,
pub dir: Vec3,
pub radius: f32,
/* private fields */
}Fields
p1: Vec3dir: Vec3radius: f32Implementations
Sourceimpl Cylinder
impl Cylinder
pub const fn new(p1: Vec3, p2: Vec3, radius: f32) -> Self
Sourcepub fn from_center_orientation(
center: DVec3,
orientation: DMat3,
radius: f64,
length: f64,
) -> Self
pub fn from_center_orientation( center: DVec3, orientation: DMat3, radius: f64, length: f64, ) -> Self
Create a Cylinder from center, orientation (DMat3), radius, and length.
The cylinder axis is along the orientation’s Y column.
Sourcepub fn to_center_orientation_length(&self) -> (DVec3, DMat3, f64)
pub fn to_center_orientation_length(&self) -> (DVec3, DMat3, f64)
Extract center, orientation (DMat3), and length from this cylinder.
pub fn p2(&self) -> Vec3
pub fn bounding_sphere(&self) -> (Vec3, f32)
Sourcepub fn point_dist_sq(&self, p: Vec3) -> f32
pub fn point_dist_sq(&self, p: Vec3) -> f32
Squared distance from a point to the nearest point on the cylinder surface/interior.
Sourcepub fn contains_point(&self, p: Vec3) -> bool
pub fn contains_point(&self, p: Vec3) -> bool
Returns true if the point lies inside or on the cylinder surface.
Sourceimpl Cylinder
impl Cylinder
Sourcepub fn broadphase(&self) -> Sphere
pub fn broadphase(&self) -> Sphere
Sourcepub fn obb(&self) -> Cuboid
pub fn obb(&self) -> Cuboid
See Bounded::obb
Sourcepub fn aabb(&self) -> Cuboid
pub fn aabb(&self) -> Cuboid
See Bounded::aabb